@@ -21,7 +21,7 @@ void pyPrintPretty(py::handle obj) {
 
 #define UNEXPORT __attribute__ ((visibility("hidden")))
 
-constexpr auto TESTED_YTMUSICAPI_VERSION = "0.21.0";
+constexpr auto TESTED_YTMUSICAPI_VERSION = "0.22.0";
 
 struct UNEXPORT YTMusicPrivate {
     py::scoped_interpreter guard {};
@@ -358,7 +358,7 @@ artist::Artist YTMusic::get_artist(const std::string &channel_id) const
         artist["views"].cast<std::optional<std::string>>(),
         artist["name"].cast<std::string>(),
         artist["channelId"].cast<std::string>(),
-        artist["subscribers"].cast<std::string>(),
+        artist["subscribers"].cast<std::optional<std::string>>(),
         artist["subscribed"].cast<bool>(),
         extract_py_list<meta::Thumbnail>(artist["thumbnails"]),
         extract_artist_section<artist::Artist::Song>(artist, "songs"),
@@ -460,10 +460,12 @@ video_info::VideoInfo YTMusic::extract_video_info(const std::string &video_id) c
     using namespace pybind11::literals;
 
     const auto info = d->get_ytdl().attr("extract_info")(video_id, "download"_a=py::bool_(false));
-
+    
     return {
         info["id"].cast<std::string>(),
         info["title"].cast<std::string>(),
+        info.contains("artist") ? info["artist"].cast<std::string>() : "",
+        info.contains("channel") ? info["channel"].cast<std::string>() : "",
         extract_py_list<video_info::Format>(info["formats"]),
         info["thumbnail"].cast<std::string>()
     };
